Learn R Programming

ggpattern (version 0.1.3)

convert_r_colour_to_magick_colour: Convert an R colour to a magick colour

Description

Convert an R colour to a magick colour

Usage

convert_r_colour_to_magick_colour(col)

Arguments

col

may be a built in colour, like 'tomato' or a hex colour

Value

always returns a hex colour, except if col is NA when it retuns a special magick colour 'none', which means transparent