Learn R Programming

ggpattern (version 0.1.3)

fill_area_with_img_squish: Resize image, ignoring aspect, such that both the target width and height is achieved.

Description

Unless the width and height are carefully chosen, this operation will distort the image to force it to fit the dimensions

Usage

fill_area_with_img_squish(img, width, height, filter = "lanczos")

Arguments

img

magick image

width

target dimensions for final image

height

target dimensions for final image

filter

default: lanczos

Value

magick image of the required dimensions

Examples

Run this code
# NOT RUN {
filename <- system.file("img", "Rlogo.png", package="png")
img <- magick::image_read(filename)
fill_area_with_img_squish(img, 100, 400)
# }

Run the code above in your browser using DataLab