powered by
Unless the width and height are carefully chosen, this operation will distort the image to force it to fit the dimensions
fill_area_with_img_squish(img, width, height, filter = "lanczos")
magick image
target dimensions for final image
default: lanczos
magick image of the required dimensions
# NOT RUN { filename <- system.file("img", "Rlogo.png", package="png") img <- magick::image_read(filename) fill_area_with_img_squish(img, 100, 400) # }
Run the code above in your browser using DataLab